#
# bdomain.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees import *

class BDomain:
    def __init__(self, bees, name):
        self.bees = bees
        if not name == "":
            self.bees.msg.pushSpecifier("bdomain", name)

    def create(self, name, selector, args=[], capabilities=[],
               countPermissions={}):
        self.bees.msg.setWhat(JSI_CREATE_PROPERTY)
        self.bees.msg.pushSpecifier("bdomain")
        self.bees.msg.add("name", name)
        self.bees.msg.add("selector", selector)
        for arg in args:
            self.bees.msg.add("arg", arg)
        for capability in capabilities:
            self.bees.msg.add("capability", capability)
        self.bees.addPermissions(countPermissions=countPermissions)
        reply = self.bees.send()
        return reply.find("result")

    def delete(self):
        self.bees.msg.setWhat(JSI_DELETE_PROPERTY)
        self.bees.send()

    def getStats(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        reply = self.bees.send()
        threads = []
        count = reply.identifierCount("thread.name")
        lpc = 0
        while lpc < count:
            threads.append({
                "name" : reply.find("thread.name", lpc),
                "cpu-usage" : reply.find("thread.cpu-usage", lpc),
                })
            lpc = lpc + 1
        inchans = []
        count = reply.identifierCount("in.packets")
        lpc = 0
        while lpc < count:
            inchans.append({
                "protocol" : reply.find("in.protocol", lpc),
                "address" : reply.find("in.address", lpc),
                "packets" : reply.find("in.packets", lpc),
                "bytes" : reply.find("in.bytes", lpc),
                "drop-packets" : reply.find("in.drop-packets", lpc),
                "drop-no-bufs" : reply.find("in.drop-no-bufs", lpc),
                "drop-failed-buf" : reply.find("in.drop-failed-buf", lpc),
                "drop-bad-packet" : reply.find("in.drop-bad-packet", lpc),
                "drop-bad-mac" : reply.find("in.drop-bad-mac", lpc),
                "drop-bytes" : reply.find("in.drop-bytes", lpc),
                "buf-queued" : reply.find("in.buf-queued", lpc),
                "buf-copies" : reply.find("in.buf-copies", lpc),
                "max-threads" : reply.find("in.max-threads", lpc),
                })
            lpc = lpc + 1
        outchans = []
        count = reply.identifierCount("out.packets")
        lpc = 0
        while lpc < count:
            outchans.append({
                "protocol" : reply.find("out.protocol", lpc),
                "address" : reply.find("out.address", lpc),
                "packets" : reply.find("out.packets", lpc),
                "bytes" : reply.find("out.bytes", lpc),
                "buf-copies" : reply.find("out.buf-copies", lpc),
                })
            lpc = lpc + 1
        retval = {
            "domain.thread-count" : reply.find("domain.thread-count"),
            "domain.max-threads" : reply.find("domain.max-threads"),
            "domain.threads" : threads,
            "domain.in-channels" : inchans,
            "domain.out-channels" : outchans,
            }
        return retval

    def waitFor(self):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("wait")
        self.bees.send()
