#
# capabilityMap.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees import *

import sys

class CapabilityMap:
    def __init__(self, bees, name = None):
        self.bees = bees
        if name != None:
            self.bees.msg.pushSpecifier("capability", name)
        else:
            self.bees.msg.pushSpecifier("capability")

    def create(self, name):
        self.bees.msg.setWhat(JSI_CREATE_PROPERTY)
        self.bees.msg.add("name", name)
        self.bees.send()

    def delete(self):
        self.bees.msg.setWhat(JSI_DELETE_PROPERTY)
        self.bees.send()

    def exists(self):
        retval = 1
        try:
            self.bees.msg.setWhat(JSI_GET_PROPERTY)
            self.bees.send()
            return 1
        except MessageError:
            return 0

    def getChildren(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("children")
        reply = self.bees.send()
        retval = []
        ids = reply.getIdentifiers()
        for id in ids:
            retval.append(id[1])
        return retval

    def readFrom(self, file, password = ""):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("read")
        self.bees.msg.add("file", file)
        if password != "":
            self.bees.msg.add("password", password)
        self.bees.send()

    def writeTo(self, file, password = ""):
        self.bees.msg.setWhat(JSI_EXECUTE_PROPERTY)
        self.bees.msg.pushSpecifier("write")
        self.bees.msg.add("file", file)
        if password != "":
            self.bees.msg.add("password", password)
        self.bees.send()
