#
# node.py
#
# Copyright (c) 2002 The University of Utah and the Flux Group.
# All rights reserved.
#
# This file is part of the Janos Bees Software.
#
# Permission to use, copy, modify, distribute, and sell this software and
# its documentation is hereby granted without fee, provided that the above
# copyright notice and this permission/disclaimer notice is retained in all
# copies or modified versions, and that both notices appear in supporting
# documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
# WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
# ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
# 
# Users are requested, but not required, to send to csl-dist@cs.utah.edu any
# improvements that they make and grant Univ. of Utah redistribution rights.
#

from bees import *

class Node:
    def __init__(self, bees, name = ""):
        self.bees = bees
        if not name == "":
            self.bees.msg.pushSpecifier("node", name)

    def create(self, name, nodeName = "", version = "", permissions={
        "name" : "read",
        "version" : "read",
        "threadStart" : "execute",
        "jsiRegister" : "execute",
        "protocolRegister" : "execute",
        },
               clock = "clock"):
        self.bees.msg.setWhat(JSI_CREATE_PROPERTY)
        self.bees.msg.pushSpecifier("node")
        self.bees.msg.add("name", name)
        self.bees.msg.add("clock", clock)
        if nodeName != "":
            self.bees.msg.add("nodeName", nodeName)
        if version != "":
            self.bees.msg.add("version", version)
        self.bees.addPermissions(permissions=permissions)
        reply = self.bees.send()
        return reply.find("result")

    def getName(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("name")
        reply = self.bees.send()
        return reply.find("result")

    def getVersion(self):
        self.bees.msg.setWhat(JSI_GET_PROPERTY)
        self.bees.msg.pushSpecifier("version")
        reply = self.bees.send()
        return reply.find("result")
