/*
 * AuthenticatorDLPresentation.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.authenticator;

import bees.core.TypeID;
import bees.core.ProtocolPresentation;
import bees.core.DLProtocolPresentation;
import bees.core.ExtendedProtocolPresentation;

import bees.core.resource.Logger;

/**
 * A simple DLProtocolPresentation that adds extended protocols to the
 * NeighborManager.
 */
public class AuthenticatorDLPresentation
    extends DLProtocolPresentation
{
    /**
     * The Authenticator application.
     */
    private Authenticator auth;

    /**
     * The flow identifier this presentation is downloading.
     */
    private TypeID flowID;

    /**
     * Construct a AuthenticatorDLPresentation with the given values.
     *
     * @param auth The Authenticator application.
     */
    public AuthenticatorDLPresentation(Authenticator auth, TypeID flowID)
    {
	this.auth = auth;
	this.flowID = flowID;
    }

    /**
     * @see bees.core.DLProtocolPresentation#bootComplete(ProtocolPresentation)
     */
    public void bootComplete(ProtocolPresentation pp)
    {
	if( pp instanceof ExtendedProtocolPresentation )
	{
	    this.auth.getNeighborManager().
		addInterestedProtocol((ExtendedProtocolPresentation)pp);
	}
	super.bootComplete(pp);
    }

    /**
     * @see bees.core.DLProtocolPresentation#disconnected()
     */
    public void disconnected()
    {
	super.disconnected();

	this.auth.getNodeCache().remove(this.flowID);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "AuthenticatorDLPresentation["
	    + super.toString()
	    + "; auth="
	    + this.auth
	    + "; flowID="
	    + this.flowID
	    + "]";
    }
}
