/*
 * StatsCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.benchmark;

import java.io.IOException;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Assert;
import bees.core.Capsule;
import bees.core.Neighbor;
import bees.core.NodeCache;
import bees.core.ProtocolSession;
import bees.core.EncodingException;

import bees.core.resource.Logger;

import bees.core.security.IntegerPermission;

public final class StatsCapsule
    extends Capsule
    implements NodeCache.EventHandler
{
    static final IntegerPermission QUERY_FREQUENCY =
	new IntegerPermission("interval", 500);
    
    long start;
    long last;
    long packetCount;

    public StatsCapsule()
    {
    }

    public void removed(Node node, ProtocolSession ps)
    {
    }

    public IntegerPermission collected(Node node, ProtocolSession ps)
    {
	BenchmarkSession bs;

	bs = (BenchmarkSession)ps;
	synchronized( bs )
	{
	    switch( bs.state )
	    {
	    case BenchmarkSession.STATE_QUERY:
		try
		{
		    bs.next.send(this);
		}
		catch(EncodingException e)
		{
		    Logger.log(Logger.ERROR, e);
		}
		catch(IOException e)
		{
		    Logger.log(Logger.WARNING, e);
		}
		break;
	    default:
		break;
	    }
	}
	return QUERY_FREQUENCY;
    }

    public void copy(StatsCapsule sc)
    {
	Assert.require(sc);
	
	this.start = sc.start;
	this.last = sc.last;
	this.packetCount = sc.packetCount;
    }

    public void reset()
    {
	super.reset();
	
	this.start = 0;
	this.last = 0;
	this.packetCount = 0;
    }
    
    public void encode(Xdr xdr)
    {
	xdr.PUT(this.start);
	xdr.PUT(this.last);
	xdr.PUT(this.packetCount);
    }

    public void decode(Xdr xdr)
    {
	this.start = xdr.LONG();
	this.last = xdr.LONG();
	this.packetCount = xdr.LONG();
    }

    public void evaluate(Node node, ProtocolSession ps)
	throws EncodingException,
	       IOException
    {
    }
    
    public String toString()
    {
	return "StatsCapsule["
	    + super.toString()
	    + "; start="
	    + this.start
	    + "; last="
	    + this.last
	    + "; packetCount="
	    + this.packetCount
	    + "]";
    }
}
