/*
 * DiscoveryBootCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.discovery;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;

import bees.core.resource.Logger;

/**
 * A DiscoveryBootCapsule is used to boot strap the protocol domain.
 */
public final class DiscoveryBootCapsule
    extends Capsule
{
    /**
     * Construct an empty DiscoveryBootCapsule.
     */
    public DiscoveryBootCapsule()
    {
    }

    /**
     * @see bees.core.Capsule#encode(Xdr)
     */
    public void encode(Xdr xdr)
    {
    }

    /**
     * @see bees.core.Capsule#decode(Xdr)
     */
    public void decode(Xdr xdr)
    {
    }

    /**
     * @see bees.core.Capsule#evaluate(Node)
     */
    public void evaluate(Node node)
    {
	DiscoveryProtocolSession dps;
	DiscoveryParameters dp;
	
	/* Say hi. */
	Logger.log(Logger.INFO,
		   "Discovery Protocol v"
		   + DiscoveryProtocolSession.VERSION_MAJOR
		   + "."
		   + DiscoveryProtocolSession.VERSION_MINOR);

	/* Build up the parameters for this flow. */
	dps = (DiscoveryProtocolSession)this.getSession();
	dp = new DiscoveryParameters(dps);
	dp.initialize(node);
	dps.setDiscoveryParameters(dp);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "DiscoveryBootCapsule["
	    + super.toString()
	    + "]";
    }
}
