/*
 * PollRequestCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.health;

import java.util.Hashtable;
import java.util.Enumeration;
import java.util.NoSuchElementException;

import java.io.IOException;

import java.security.SignatureException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

import kaffe.sensors.Sensor;
import kaffe.sensors.SensorFeature;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Pair;
import bees.core.Panic;
import bees.core.Capsule;
import bees.core.NodeCache;
import bees.core.ProtocolSession;
import bees.core.EncodingException;
import bees.core.SignedXdrByteArray;

import bees.core.resource.Logger;

import bees.core.security.IntegerPermission;

/**
 * Capsule used to alert interested parties about a problem on the node.
 */
public class PollRequestCapsule
    extends Capsule
{
    /**
     * A signed byte array which holds the node name, sensor name, feature
     * name, and the out of bounds value.
     */
    private SignedXdrByteArray signedData;

    /**
     * Construct an empty AlertCapsule.
     */
    public PollRequestCapsule()
    {
    }

    public void decode(Xdr xdr)
    {
	HealthParameters hp;
	HealthSession hs;

	hs = (HealthSession)this.getSession();
	hp = hs.getHealthParameters();
	this.signedData = new SignedXdrByteArray(xdr.BYTES(xdr.INT()),
						 xdr.BYTES(xdr.INT()),
						 hp.getAlgorithm());
    }

    public void encode(Xdr xdr)
    {
	byte ba[];

	ba = this.signedData.buf;
	xdr.PUT(ba.length);
	xdr.PUT(ba);
	ba = this.signedData.getSignature();
	xdr.PUT(ba.length);
	xdr.PUT(ba);
    }

    public void evaluate()
    {
	if( false )
	{
	    /* do forward */
	}
	else
	{
	    HealthExtraParameters hp;
	    HealthSession hs;
	    
	    hs = (HealthSession)this.getSession();
	    hp = (HealthExtraParameters)hs.getHealthParameters();
	    try
	    {
		if( this.signedData.verify(hp.getServerPublicKey()) )
		{
		}
		else
		{
		    Logger.log("PollRequestCapsule, "
			       + this
			       + ", doesn't verify!");
		}
	    }
	    catch(SignatureException e)
	    {
		Logger.log(e);
	    }
	    catch(InvalidKeyException e)
	    {
		Logger.log(e);
	    }
	    catch(NoSuchAlgorithmException e)
	    {
		Logger.log(e);
	    }
	    catch(NoSuchElementException e)
	    {
		Logger.log("Unknown node: " + e.getMessage());
		Logger.log(e);
	    }
	}
    }
    
    public String toString()
    {
	return "PollRequestCapsule["
	    + super.toString()
	    + "; signedData="
	    + this.signedData
	    + "]";
    }
}
