/*
 * LivenessPresentation.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.liveness;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Assert;
import bees.core.Strict;
import bees.core.NeighborImpl;
import bees.core.ExternalCapsule;
import bees.core.CapabilityReference;
import bees.core.ExtendedProtocolPresentation;

/**
 * A LivnessPresentation is used to communicate with the LivenessSession in the
 * protocol's domain.
 */
public class LivenessPresentation
    extends ExtendedProtocolPresentation
{
    /**
     * Construct an empty LivenessPresentation.
     */
    public LivenessPresentation()
    {
    }

    /**
     * Ask the protocol to monitor the given neighbor.
     *
     * @param ni The neighbor to monitor.
     */
    public void monitor(NeighborImpl ni)
    {
	ExternalCapsule ec;
	Xdr xdr;

	Assert.require(ni);
	
	ec = new ExternalCapsule(new CapabilityReference[] {
	    new CapabilityReference(ni)
	}).init();
	xdr = ec.getXDR();
	xdr.PUT(LivenessSession.METHOD_MONITOR);
	this.sendCapsule(ec);
    }

    /**
     * Callback for handling lost neighbors.
     *
     * @param cr The reference to the lost neighbor.
     */
    public void lost(CapabilityReference cr)
    {
    }

    /**
     * @see bees.core.ExtendedProtocolPresentation#userReceive(Node, int, ExternalCapsule)
     */
    public final void userReceive(Node node, int method, ExternalCapsule ec)
    {
	Xdr xdr;

	xdr = ec.getXDR();
	switch( method )
	{
	case LivenessSession.METHOD_LOST:
	    this.lost(ec.getReferences()[0]);
	    break;
	default:
	    Strict.fail("Bogus method: " + Integer.toHexString(method));
	    break;
	}
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "LivenessPresentation["
	    + super.toString()
	    + "]";
    }
}
