/*
 * PathfinderBootCapsule.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package apps.pathfinder;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.Capsule;
import bees.core.DLProtocolSession;

import bees.core.resource.Logger;

/**
 * Boot capsule used when the pathfinder is acting alone (not a companion).
 * <p>
 * This is only used for debugging purposes.
 */
public class PathfinderBootCapsule
    extends Capsule
{
    /**
     * Construct an empty PathfinderBootCapsule.
     */
    public PathfinderBootCapsule()
    {
    }

    /**
     * @see bees.core.Capsule#encode(Xdr)
     */
    public void encode(Xdr xdr)
    {
    }

    /**
     * @see bees.core.Capsule#decode(Xdr)
     */
    public void decode(Xdr xdr)
    {
    }

    /**
     * @see bees.core.Capsule#evaluate(Node)
     */
    public void evaluate(Node node)
	throws Throwable
    {
	PathfinderSession pfs;
	DLProtocolSession dps;
	
	/* Say hi. */
	Logger.log(Logger.INFO,
		   "Pathfinder Protocol v"
		   + PathfinderSession.VERSION_MAJOR
		   + "."
		   + PathfinderSession.VERSION_MINOR);

	pfs = (PathfinderSession)this.getSession();
	dps = (DLProtocolSession)
	    this.getSession("bees.core.DLProtocolSession");
	if( dps.getPreviousNeighbor() != null )
	{
	    pfs.configure(node, this);
	}
	else
	{
	    pfs.configureRoot(node, this);
	}
	node.beginManagement(pfs);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "PathfinderBootCapsule["
	    + super.toString()
	    + "]";
    }
}
