/*
 * BeesDemultiplexKey.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import edu.utah.janos.nodeos.Domain;

import bees.core.anep.ANEPDemultiplexKey;

import bees.util.MD5;

/**
 * Match Bees packets for a specific Bees protocol.
 *
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
class BeesDemultiplexKey
    extends ANEPDemultiplexKey
{
    /**
     * Construct an BeesDemultiplexKey that matches packets with the given
     * parameters.
     *
     * @param domain The current domain.
     * @param cidBytes The bytes representing the identifier for a specific
     * capsule type.
     */
    BeesDemultiplexKey(Domain domain, byte[] cidBytes)
    {
	/* Match the ANEP header. */
	super(domain, BeesVersion.ANEP_TYPE);

	Assert.require(cidBytes);
	Assert.require(cidBytes.length == MD5.HASH_LENGTH);

	/* Add a match for the capsule ID. */
	this.add(Xdr.INT	/* Bees version number */
		 + Xdr.INT,	/* Bees flag bits */
		 null,
		 null);
	this.add(cidBytes.length,
		 cidBytes,
		 null);
    }

    /**
     * Construct an BeesDemultiplexKey that matches packets with the given
     * parameters.
     *
     * @param domain The current domain.
     * @param capsuleID The identifier for a capsule type.
     */
    BeesDemultiplexKey(Domain domain, TypeID capsuleID)
    {
	this(domain, capsuleID.getHash());
    }
    
    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "BeesDemultiplexKey["
	    + super.toString()
	    + "]";
    }
}
