/*
 * BeesVersion.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.kernel.BeesKernel;

/**
 * Class used to colocate the various versioning information.
 */
public final class BeesVersion
{
    /**
     * The MIT Bees type number.
     */
    public static final short ANEP_TYPE_MIT = 18;

    /**
     * The Utah Bees type number.
     */
    public static final short ANEP_TYPE_UTAH = 122;

    /**
     * The type to use in ANEP headers.
     */
    public static short ANEP_TYPE = ANEP_TYPE_UTAH;

    /**
     * The Bees version number to be placed in capsules.
     */
    public static int CAPSULE_VERSION = 0x00010001;

    /**
     * The Bees version number, encoded as bytes, to be placed in capsules.
     */
    public static byte CAPSULE_VERSION_BYTES[] = new byte[] {
	0x00, 0x01, 0x00, 0x01
    };

    /**
     * The version string used for builtin protocols.
     */
    public static String BUILTIN_PROTOCOL_VERSION = "2002 Prototype";
    
    /**
     * The version string node.getVersion() returns.
     */
    public static String NODE_VERSION = "Bees v"
	+ BeesKernel.getInfoTree().getProperty("bees.version");

    /**
     * @return A string containing the version values.
     */
    public static String staticToString()
    {
	return "BeesVersion[ANEP_TYPE_MIT="
	    + ANEP_TYPE_MIT
	    + "; ANEP_TYPE_UTAH="
	    + ANEP_TYPE_UTAH
	    + "; ANEP_TYPE="
	    + ANEP_TYPE
	    + "; CAPSULE_VERSION="
	    + Integer.toHexString(CAPSULE_VERSION)
	    + "; BUILTIN_PROTOCOL_VERSION="
	    + BUILTIN_PROTOCOL_VERSION
	    + "; NODE_VERSION="
	    + NODE_VERSION
	    + "]";
    }
    
    /**
     * Private constructor, static-only class.
     */
    private BeesVersion()
    {
    }
}
