/*
 * FlowIdentifierFactory.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.NoSuchElementException;

import bees.core.kernel.KernelObjectCoroutine;

import bees.core.bdomain.BDomain;

import bees.core.security.PermissionSet;

public final class FlowIdentifierFactory
    extends Capability
{
    private BDomain bdomain;
    
    public FlowIdentifierFactory()
    {
    }

    protected void bindToObject(Object obj)
    {
	if( this.bdomain == null )
	{
	    this.bdomain = BDomain.currentBDomain();
	}
	else
	{
	    throw new SecurityException();
	}
    }

    public synchronized void revoke()
    {
	super.clear();
	
	this.bdomain = null;
    }

    static FlowIdentifier create(BDomain bdomain, TypeID tid, String comment)
    {
	return (FlowIdentifier)KernelObjectCoroutine.
	    create(new FlowIdentifier(),
		   bdomain.getBDomainCoroutine(),
		   tid.getHash(),
		   comment);
    }

    public synchronized FlowIdentifier create(TypeID tid, String comment)
    {
	return create(this.bdomain, tid, comment);
    }

    public synchronized FlowIdentifier create(TypeID tid)
    {
	return create(this.bdomain, tid, "Domain Identifier");
    }

    public String toString()
    {
	return "FlowIdentifierFactory["
	    + super.toString()
	    + "]";
    }
}
