/*
 * IDTranslationProtocol.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import bees.core.kernel.KernelPanic;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.VersionString;
import bees.core.security.CountPermission;

/**
 * The IDTranslationProtocol detects unknown Capsule types and translates their
 * Capsule identifiers to flow identifiers.
 */
public final class IDTranslationProtocol
    extends Protocol
    implements BuiltinProtocol,
	       CapsuleCompanionProtocol,
	       FlowIndependentCompanionProtocol
{
    /**
     * Construct the IDTranslationProtocol description.
     */
    public IDTranslationProtocol()
    {
	try
	{
	    Node node = super.getNode();
	    
	    this.startProtocolDefn();
	    {
		this.addCapsule("bees.core.UnknownCapsule",
				(VersionString)node.
				getSystemCapability("idversion"),
				new PermissionSet(new Permission[] {
				    new CountPermission("threadCount", 0),
				    new CountPermission("bufferCount", 0),
				    
				    new CountPermission(
					"transformTo."
					+ "bees.core.IDTranslatorCapsule", 1),
				}));
		this.addCapsule("bees.core.IDTranslatorCapsule",
				(VersionString)node.
				getSystemCapability("idversion"),
				new PermissionSet(new Permission[] {
				    new CountPermission("initial", 1),
				    new CountPermission("externals", 1),
				    new CountPermission("returns", 1),
				    
				    new CountPermission("threadCount", 1),
				    new CountPermission("bufferCount", 1),
				    
				    new CountPermission(
					"transformTo."
					+ "bees.core.UnknownCapsule", 1),
				}));
		this.setBootStrap("bees.core.IDTranslatorBootCapsule",
				  new PermissionSet(new Permission[] {
				      new CountPermission("transforms", 1),
				      
				      new CountPermission("threadCount", 0),
				      new CountPermission("bufferCount", 0),
				  }));
		this.setSession("bees.core.IDTranslatorSession");
	    }
	    this.endProtocolDefn();
	}
	catch(ClassNotFoundException e)
	{
	    throw new Panic(e);
	}
    }

    public String toString()
    {
	return "IDTranslationProtocol["
	    + super.toString()
	    + "]";
    }
}
