/*
 * LocalFlowEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.io.IOException;

import edu.utah.janos.nodeos.Domain;

import bees.core.resource.Logger;

import bees.core.bdomain.BDomain;
import bees.core.bdomain.DeadBDomainException;

public final class LocalFlowEvent
    extends TwoWayBeesEvent
{
    private byte protocolDomain[];
    
    LocalFlowEvent(LocalFlowCoroutine lfc, byte pf[])
    {
	super(lfc);
	
	this.protocolDomain = pf;
    }

    byte[] getProtocolFlow()
    {
	return this.protocolDomain;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	this.protocolDomain = null;
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	LocalFlowEvent lfe;

	lfe = (LocalFlowEvent)retval;
	if( this.protocolDomain != null )
	    lfe.protocolDomain = (byte[])this.protocolDomain.clone();
	return retval;
    }

    public String toString()
    {
	return "LocalFlowEvent["
	    + super.toString()
	    + "; protocolDomain="
	    + ByteArray.toString(this.protocolDomain, 32)
	    + "]";
    }
}
