/*
 * MissingPairException.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

/**
 * Exception thrown when a pair couldn't be found.
 */
public class MissingPairException
    extends Exception
{
    /**
     * The missing tag name.
     */
    private final String tag;
    
    /**
     * The missing tag instance.
     */
    private final int instance;
    
    /**
     * Construct a MissingPairException with the given values.
     *
     * @param tag The missing tag name.
     * @param instance The missing tag instance.
     */
    public MissingPairException(String tag, int instance)
    {
	super("No pair with tag=" + tag + " and instance=" + instance);

	this.tag = tag;
	this.instance = instance;
    }

    /**
     * @return The missing tag name.
     */
    public String getTag()
    {
	return this.tag;
    }

    /**
     * @return The missing tag instance.
     */
    public int getInstance()
    {
	return this.instance;
    }
}
