/*
 * NodeSpec.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

public class NodeSpec
    extends Capability
    implements CapabilitySpec
{
    private String name;
    private String version;
    
    /**
     * @param name The name of the node.
     * @param version The version of Bees the node is running.
     * @return A flattened version of the inputs.
     */
    static byte[] marshal(String name, String version)
    {
	XdrByteArray xba;

	xba = new XdrByteArray(Xdr.STRING(name) + Xdr.STRING(version));
	xba.PUT(name);
	xba.PUT(version);
	return xba.toBytes();
    }

    public NodeSpec(String name, String version)
    {
	this.name = name;
	this.version = version;
    }
    
    public NodeSpec()
    {
	this(null, null);
    }
    
    public synchronized CapabilitySpec specFromBytes(byte flattened[])
    {
	XdrByteArray xba;
	
	xba = new XdrByteArray(flattened);
	this.name = xba.STRING();
	this.version = xba.STRING();
	return this;
    }

    public SpecCapabilityFactory getFactory()
    {
	return null;
    }

    public synchronized byte[] toBytes()
    {
	return marshal(this.name, this.version);
    }
    
    /**
     * @return The name of this node.
     */
    public String getName()
    {
	return this.name;
    }

    /**
     * @return The the version of Bees on this node.
     */
    public String getVersion()
    {
	return this.version;
    }

    public String toString()
    {
	return "NodeSpec["
	    + super.toString()
	    + "]";
    }
}
