/*
 * ProtocolPresentation.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.util.Hashtable;

import edu.utah.janosvm.sys.DeadTeamException;
import edu.utah.janosvm.sys.TeamEjectionException;

import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

import bees.core.security.PermissionSet;

import bees.core.bdomain.BDomain;
import bees.core.bdomain.BDomainLocal;
import bees.core.bdomain.DeadBDomainException;

/**
 * A ProtocolPresentation is a base for classes that applications can use when
 * communicating with ProtocolSessions.  Basically, a ProtocolPresentation
 * gives the application programmer a friendlier interface to a protocol than
 * manually creating and sending ExternalCapsules.
 */
public abstract class ProtocolPresentation
    implements ExternalCapsuleReceiver,
	       ExternalChannel
{
    /**
     * The coroutine connected to the protocol domain.
     */
    private ExternalCoroutine ec;

    /**
     * Construct an empty ProtocolPresentation.
     */
    protected ProtocolPresentation()
    {
    }

    public void setLocal(Object obj)
    {
    }

    public Object getLocal()
    {
	return null;
    }

    /**
     * @param ec The coroutine connected to the protocol domain.
     * @return this
     */
    ProtocolPresentation setCoroutine(ExternalCoroutine ec)
    {
	this.ec = ec;
	return this;
    }

    /**
     * @return The coroutine connected to the protocol domain.
     */
    ExternalCoroutine getCoroutine()
    {
	return this.ec;
    }

    /**
     * @param ec The ExternalCapsule to send to the protocol.
     */
    public void sendCapsule(ExternalCapsule ec)
    {
	this.ec.sendCapsule(ec);
    }

    public void recycleCapsule(ExternalCapsule ec)
    {
    }

    protected void revoke(Capability cap)
    {
	try
	{
	    RevokeCapabilityCoroutine rcc;
	    
	    rcc = new RevokeCapabilityCoroutine();
	    rcc.revoke(this.ec.getChannel(), cap);
	}
	catch(DeadBDomainException e)
	{
	}
    }
    
    protected void revokePermissions(Capability cap, PermissionSet ps)
    {
	try
	{
	    RevokeCapabilityCoroutine rcc;
	    
	    rcc = new RevokeCapabilityCoroutine();
	    rcc.revokePermissions(this.ec.getChannel(), cap, ps);
	}
	catch(DeadBDomainException e)
	{
	}
    }

    public void disconnected()
    {
    }

    public String toString()
    {
	return "ProtocolPresentation[ec="
	    + this.ec
	    + "]";
    }
}
