/*
 * TwoWayBeesEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;

import edu.utah.janos.nodeos.DomainStartException;

import bees.core.resource.Logger;

/**
 * A base class for BeesEvents that will be both a request and reply.
 */
public class TwoWayBeesEvent
    extends BeesEvent
{
    private static final Class constructorArgTypes[] = {
	String.class
    };

    private static final Panic catastrophePanic =
	new Panic("Uh, Something really bad happened");
    
    private Class throwableClass;
    private String throwableMessage;

    public TwoWayBeesEvent(Coroutine coroutine)
    {
	super(coroutine);
	
	super.useBDomainReplyPort();
    }

    public final void setThrowable(Throwable th)
    {
	this.throwableClass = th.getClass();
	this.throwableMessage = th.getMessage();
    }

    public final Class getThrowableClass()
    {
	return this.throwableClass;
    }

    public final String getThrowableMessage()
    {
	return this.throwableMessage;
    }

    public Throwable getThrowable()
    {
	Throwable retval = null;
	
	if( this.throwableClass != null )
	{
	    try
	    {
		try
		{
		    Constructor cons;
		    
		    cons = this.throwableClass.
			getConstructor(constructorArgTypes);
		    retval = (Throwable)cons.newInstance(new Object[] {
			this.throwableMessage
		    });
		}
		catch(Throwable th)
		{
		    Logger.log(th);
		    retval = new Panic("Exception while creating "
				       + "coroutine's peer exception!",
				       th);
		}
	    }
	    catch(Throwable th)
	    {
		retval = catastrophePanic;
	    }
	}
	return retval;
    }

    public Object clone()
    {
	Object retval = super.clone();
	TwoWayBeesEvent ae;

	ae = (TwoWayBeesEvent)retval;
	if( this.throwableMessage != null )
	{
	    ae.throwableMessage = CloneFactory.clone(this.throwableMessage);
	}
	return retval;
    }
    
    public String toString()
    {
	return "TwoWayBeesEvent["
	    + super.toString()
	    + "; throwableClass="
	    + this.throwableClass
	    + "; message="
	    + this.throwableMessage
	    + "]";
    }
}
