/*
 * BDomainRegister.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import java.util.Vector;
import java.util.Hashtable;
import java.util.Enumeration;

import edu.utah.janosvm.sys.DeadTeamException;
import edu.utah.janosvm.sys.TeamEjectionException;

import edu.utah.janosvm.kit.comm.amiga.FaxPort;
import edu.utah.janosvm.kit.comm.amiga.Facsimile;
import edu.utah.janosvm.kit.comm.amiga.SignalSet;
import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

import edu.utah.janosvm.kit.comm.jsi.JSIPair;
import edu.utah.janosvm.kit.comm.jsi.JSIHandler;
import edu.utah.janosvm.kit.comm.jsi.JSIMessage;
import edu.utah.janosvm.kit.comm.jsi.JSIPropertyInfo;
import edu.utah.janosvm.kit.comm.jsi.JSIHandlerContext;
import edu.utah.janosvm.kit.comm.jsi.MissingPairException;

import edu.utah.janos.nodeos.ThreadLocal;

import bees.core.ByteArray;
import bees.core.Coroutine;
import bees.core.Capability;
import bees.core.EventChannel;
import bees.core.CapabilityFactory;

import bees.core.security.Permission;

import bees.core.bdomain.BDomain;
import bees.core.bdomain.EventHandler;

final class BDomainRegister
{
    static final ThreadLocal registry = new ThreadLocal() {
	    protected Object initialValue()
	    {
		throw new KernelPanic("XXX BDomainRegister wasn't created.");
	    }
	};

    private final FaxPort fp = EventHandler.getHandlerPort();
    private final Hashtable idToBDomainMap = new Hashtable();
    
    BDomainRegister()
    {
    }

    synchronized int size()
    {
	return this.idToBDomainMap.size();
    }

    synchronized Enumeration keys()
    {
	return this.idToBDomainMap.keys();
    }

    synchronized Enumeration elements()
    {
	return this.idToBDomainMap.elements();
    }

    synchronized boolean containsKey(BDomainIdentifier si)
    {
	return this.idToBDomainMap.containsKey(si);
    }

    synchronized void put(BDomainCoroutine sc)
    {
	this.idToBDomainMap.put(sc.getBDomainIdentifier(), sc);
    }

    synchronized BDomainCoroutine get(BDomainIdentifier si)
    {
	return (BDomainCoroutine)this.idToBDomainMap.get(si);
    }

    synchronized BDomainCoroutine remove(BDomainIdentifier si)
    {
	return (BDomainCoroutine)this.idToBDomainMap.remove(si);
    }
    
    public String toString()
    {
	return "BDomainRegister[fp="
	    + this.fp
	    + "; idToBDomainMap="
	    + this.idToBDomainMap
	    + "]";
    }
}
