/*
 * BDomainRegisterEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import bees.core.Assert;
import bees.core.TwoWayBeesEvent;

import bees.core.bdomain.DeadBDomainException;

final class BDomainRegisterEvent
    extends TwoWayBeesEvent
{
    static final int METHOD_MIN = 0;
    static final int METHOD_CREATE = 0;
    static final int METHOD_DELETE = 1;
    static final int METHOD_MAX = 2;

    private final int method;
    
    BDomainRegisterEvent(BDomainRegisterCoroutine src, int method)
    {
	super(src);
	
	Assert.require(method >= METHOD_MIN);
	Assert.require(method < METHOD_MAX);
	
	this.method = method;
    }

    int getMethod()
    {
	return this.method;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	BDomainRegisterEvent sre;

	sre = (BDomainRegisterEvent)retval;
	return retval;
    }

    public String toString()
    {
	return "BDomainRegisterEvent["
	    + super.toString()
	    + "; method="
	    + this.method
	    + "]";
    }
}
