/*
 * BDomainRunningEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

import bees.core.Assert;
import bees.core.BeesEvent;

import bees.core.bdomain.DeadBDomainException;

final class BDomainRunningEvent
    extends BeesEvent
{
    private FaxPortHandle port;
    
    BDomainRunningEvent(BDomainCoroutine sc, FaxPortHandle port)
    {
	super(sc);

	Assert.require(port);
	
	this.port = port;
    }

    FaxPortHandle getPort()
    {
	return this.port;
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	this.port = null;
	super.sendReply();
    }
    
    public Object clone()
    {
	Object retval = super.clone();
	BDomainRunningEvent sre;

	sre = (BDomainRunningEvent)retval;
	if( this.port != null )
	{
	    sre.port = this.port.cloneHandle();

	    Assert.ensure(sre.port);
	}
	return retval;
    }

    public String toString()
    {
	return "BDomainRunningEvent["
	    + super.toString()
	    + "; port="
	    + this.port
	    + "]";
    }
}
