/*
 * CreateBDomainEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.amiga.Facsimile;

import edu.utah.janos.nodeos.MemSpec;
import edu.utah.janos.nodeos.DomainClassSpec;
import edu.utah.janos.nodeos.ThreadPoolSpec;

import bees.core.Assert;
import bees.core.ByteArray;
import bees.core.CloneFactory;
import bees.core.TwoWayBeesEvent;
import bees.core.CapabilityReference;

import bees.core.security.PermissionSet;

import bees.core.bdomain.DeadBDomainException;

final class CreateBDomainEvent
    extends TwoWayBeesEvent
{
    private byte id[];
    private KernelString description;
    private KernelString selector;
    private String args[];
    private CapabilityReference meters[];
    private PermissionSet meterSpec;

    private long storeID = -1;
    
    CreateBDomainEvent(CreateBDomainCoroutine csc,
		       byte id[],
		       String description,
		       String selector,
		       String args[],
		       CapabilityReference meters[],
		       PermissionSet meterSpec)
    {
	super(csc);
	
	int lpc, size;

	Assert.require(description);
	Assert.require(selector);
	Assert.require(args);

	this.id = id;
	this.description = new KernelString(description);
	this.selector = new KernelString(selector);
	this.args = args;
	this.meters = meters;
	this.meterSpec = meterSpec;
    }
    
    byte[] getID()
    {
	return this.id;
    }

    KernelString getDescription()
    {
	return this.description;
    }

    KernelString getSelector()
    {
	return this.selector;
    }

    String[] getArgs()
    {
	return this.args;
    }

    CapabilityReference[] getMeters()
    {
	return this.meters;
    }

    PermissionSet getMeterSpec()
    {
	return this.meterSpec;
    }

    void setStoreID(long storeID)
    {
	this.storeID = storeID;
    }

    long getStoreID()
    {
	return this.storeID;
    }
    
    protected void sendReply()
	throws DeadBDomainException
    {
	this.id = null;
	this.description = null;
	this.selector = null;
	this.args = null;
	this.meters = null;
	this.meterSpec = null;
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	CreateBDomainEvent cse;
	int lpc;

	cse = (CreateBDomainEvent)retval;
	if( this.id != null )
	    cse.id = (byte[])this.id.clone();
	if( this.description != null )
	    cse.description = (KernelString)this.description.clone();
	if( this.selector != null )
	    cse.selector = (KernelString)this.selector.clone();
	if( this.args != null )
	{
	    cse.args = new String[this.args.length];
	    for( lpc = 0; lpc < this.args.length; lpc++ )
	    {
		cse.args[lpc] = CloneFactory.clone(this.args[lpc]);
	    }
	}
	if( this.meters != null )
	{
	    cse.meters = new CapabilityReference[this.meters.length];
	    for( lpc = 0; lpc < this.meters.length; lpc++ )
	    {
		cse.meters[lpc] = (CapabilityReference)
		    this.meters[lpc].clone();
	    }
	}
	if( this.meterSpec != null )
	    cse.meterSpec = (PermissionSet)this.meterSpec.clone();
	return retval;
    }
    
    public String toString()
    {
	return "CreateBDomainEvent["
	    + super.toString()
	    + "; id="
	    + ByteArray.toString(this.id)
	    + "; description="
	    + this.description
	    + "; selector="
	    + this.selector
	    + "; args="
	    + this.args
	    + "; storeID="
	    + this.storeID
	    + "]";
    }
}
