/*
 * JSIEvent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.jsi.JSIPair;
import edu.utah.janosvm.kit.comm.jsi.JSIHandler;
import edu.utah.janosvm.kit.comm.jsi.JSIMessage;
import edu.utah.janosvm.kit.comm.jsi.JSIPropertyInfo;
import edu.utah.janosvm.kit.comm.jsi.JSIHandlerContext;
import edu.utah.janosvm.kit.comm.jsi.JSIEncodingException;
import edu.utah.janosvm.kit.comm.jsi.MissingPairException;

import bees.core.TwoWayBeesEvent;

import bees.core.bdomain.DeadBDomainException;

/**
 * Event used by the JSICoroutine.
 */
final class JSIEvent
    extends TwoWayBeesEvent
{
    /**
     * The flattened JSIMessage.
     */
    private byte msg[];

    /**
     * Construct a JSIEvent with the given values.
     *
     * @param jc The JSICoroutine sending this event.
     * @param jm The JSIMessage to transport.
     */
    JSIEvent(JSICoroutine jc, JSIMessage jm)
    {
	super(jc);
	
	this.setMessage(jm);
    }

    /**
     * @param jm The JSIMessage to transport.
     */
    void setMessage(JSIMessage jm)
    {
	this.msg = jm.flatten();
    }

    /**
     * @return The flattened JSIMessage.
     */
    byte[] getFlattenedMessage()
    {
	return this.msg;
    }

    /**
     * @return The instantiated JSIMessage.
     * @exception Throws a JSIEncodingException if the message couldn't be
     * instantiated. 
     */
    JSIMessage getMessage()
	throws JSIEncodingException
    {
	return JSIMessage.instantiate(this.msg);
    }

    protected void sendReply()
	throws DeadBDomainException
    {
	super.sendReply();
    }

    public Object clone()
    {
	Object retval = super.clone();
	JSIEvent je;

	je = (JSIEvent)retval;
	if( this.msg != null )
	    je.msg = (byte[])this.msg.clone();
	return retval;
    }
    
    public String toString()
    {
	return "JSIEvent["
	    + super.toString()
	    + "; msg="
	    + this.msg
	    + "]";
    }
}
