/*
 * KernelPanic.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import bees.core.Panic;

/**
 * Error thrown when there is an internal error in the kernel.
 */
public class KernelPanic
    extends Panic
{
    /**
     * Construct a KernelPanic object with the given values.
     *
     * @param msg The message to pass up to Throwable.
     */
    public KernelPanic(String msg)
    {
	super(msg);
    }

    /**
     * Construct a KernelPanic object with the given values.
     *
     * @param th The Throwable object that caused the problem.
     */
    public KernelPanic(Throwable th)
    {
	super(th);
    }

    /**
     * Construct a KernelPanic object with the given values.
     *
     * @param msg The message to pass up to Throwable.
     * @param th The Throwable object that caused the problem.
     */
    public KernelPanic(String msg, Throwable th)
    {
	super(msg, th);
    }

    public String toString()
    {
	return "KernelPanic["
	    + super.toString()
	    + "]";
    }
}
