/*
 * KernelPortHandle.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

import edu.utah.janosvm.kit.comm.commspace.CommSpaceable;

import bees.core.Assert;

/**
 * A CommSpaceable object for transporting the kernel's fax port to the child
 * domains.
 */
public final class KernelPortHandle
    implements CommSpaceable
{
    /**
     * The Kernel's fax port.
     */
    private final FaxPortHandle port;

    /**
     * @param port The Kernel's fax port.
     */
    KernelPortHandle(FaxPortHandle port)
    {
	Assert.require(port);
	
	this.port = port;
    }

    /**
     * @return The Kernel's fax port.
     */
    FaxPortHandle getPort()
    {
	return this.port;
    }

    public Object deepCopy()
    {
	return new KernelPortHandle(this.port);
    }

    public String toString()
    {
	return "KernelPortHandle[port="
	    + this.port
	    + "]";
    }
}
