/*
 * KernelString.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import bees.core.Assert;
import bees.core.CloneFactory;

/**
 * Simple class for representing bounded strings in the kernel.
 */
public final class KernelString
    implements Cloneable
{
    /**
     * The maximum length string allowed in the kernel.
     */
    static final int MAX_LENGTH = 256;

    /**
     * The string itself.
     */
    private final String str;

    /**
     * Construct a KernelString with the given value.
     *
     * @param str The string to be transferred through/held in the kernel.
     */
    public KernelString(String str)
    {
	Assert.require(str);
	
	if( str.length() > MAX_LENGTH )
	{
	    throw new IllegalArgumentException(
		"String too long to hold in the kernel.");
	}
	this.str = str;
    }

    /**
     * @return The string.
     */
    public String getString()
    {
	return this.str;
    }

    public int hashCode()
    {
	return this.str.hashCode();
    }

    public boolean equals(Object obj)
    {
	boolean retval = false;

	if( obj instanceof KernelString )
	{
	    KernelString ks = (KernelString)obj;
	    
	    retval = this.str.equals(ks.str);
	}
	return retval;
    }

    public Object clone()
    {
	return new KernelString(CloneFactory.clone(this.str));
    }
    
    public String toString()
    {
	return "KernelString[str="
	    + this.str
	    + "]";
    }
}
