/*
 * PortPair.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.kernel;

import edu.utah.janosvm.kit.comm.amiga.FaxPort;
import edu.utah.janosvm.kit.comm.amiga.FaxPortHandle;

/**
 * A simple object to hold a pair of FaxPort's.
 */
public final class PortPair
{
    /**
     * The FaxPort local to this process/team/bdomain/whatever...
     */
    private FaxPort local;
    
    /**
     * The FaxPortHandle for the remote process/team/bdomain/whatever...
     */
    private FaxPortHandle remote;

    /**
     * Construct a PortPair with the given values.
     *
     * @param local The local FaxPort.
     * @param remote The remote FaxPortHandle.
     */
    public PortPair(FaxPort local, FaxPortHandle remote)
    {
	this.local = local;
	this.remote = remote;
    }

    /**
     * Construct an empty port pair.
     */
    public PortPair()
    {
	this(null, null);
    }

    /**
     * @param port The local FaxPort.
     */
    public void setLocal(FaxPort port)
    {
	this.local = port;
    }

    /**
     * @return The FaxPort local to this process/team/bdomain/whatever...
     */
    public FaxPort getLocal()
    {
	return this.local;
    }

    /**
     * @param port The remote FaxPortHandle.
     */
    public void setRemote(FaxPortHandle port)
    {
	this.remote = port;
    }

    /**
     * @return The FaxPortHandle for the remote process/team/bdomain/whatever...
     */
    public FaxPortHandle getRemote()
    {
	return this.remote;
    }
    
    public String toString()
    {
	return "PortPair[local="
	    + this.local
	    + "; remote="
	    + this.remote
	    + "]";
    }
}
