/*
 * AccountSpec.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.resource;

import bees.core.PairChain;
import bees.core.Capability;
import bees.core.CapabilitySpec;
import bees.core.SpecCapabilityFactory;

public class AccountSpec
    extends Capability
    implements CapabilitySpec
{
    private PairChain pc;

    public AccountSpec(PairChain pc)
    {
	this.pc = pc;
    }

    /**
     * Construct an empty AccountSpec object.
     */
    public AccountSpec()
    {
	this(null);
    }

    /**
     * @see bees.core.CapabilitySpec#getFactory()
     */
    public SpecCapabilityFactory getFactory()
    {
	return null;
    }
    
    /**
     * @see bees.core.CapabilitySpec#specFromBytes(byte[])
     */
    public final synchronized CapabilitySpec specFromBytes(byte flattened[])
    {
	this.pc = PairChain.instantiate(flattened);
	return this;
    }

    public synchronized byte[] toBytes()
    {
	return this.pc.toBytes();
    }

    public synchronized void revoke()
    {
	super.clear();

	this.pc = null;
    }

    public PairChain getPairChain()
    {
	return this.pc;
    }

    public String toString()
    {
	return "AccountSpec["
	    + super.toString()
	    + "; pc="
	    + this.pc
	    + "]";
    }
}
