/*
 * AddressComponent.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.resource;

import bees.core.security.Permission;

/**
 * An AddressComponent is used to translate a permission to a string that
 * can be used in a NodeOS address specification.
 *
 * @see bees.core.resource.NodeOSNeighborFactory
 */
public interface AddressComponent
{
    /**
     * Map an address slot type and value to a string suitable for use in a
     * NodeOS address specification.
     *
     * @param type A string describing the type of address component.
     * @param what The value to be used when generating the string.
     * @return The address component string.
     */
    String map(String type, Permission what);
}
