/*
 * NetworkService.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.resource;

import bees.core.Capability;
import bees.core.CapabilityEnvelope;

/**
 * A NetworkService governs access to subdivisions of NetworkInterfaces, for
 * example, UDP ports in a UDP/IP environment.
 */
public final class NetworkService
    extends Capability
{
    /**
     * The NetworkInterface services will be provided over.
     */
    private NetworkInterface ni;

    /**
     * Construct an empty NetworkService capability.
     */
    public NetworkService()
    {
    }

    /**
     * @return The NetworkInterface services will be provided over.
     */
    NetworkInterface getNetworkInterface()
    {
	return this.ni;
    }

    /**
     * @see bees.core.Capability#fromBytes(byte[], CapabilityEnvelope[])
     */
    protected synchronized void fromBytes(byte flattened[],
					  CapabilityEnvelope sub[])
	throws Exception
    {
	super.fromBytes(flattened);
	
	this.ni = (NetworkInterface)sub[0].unseal();
    }

    /**
     * @see bees.core.Capability#revoke()
     */
    public synchronized void revoke()
    {
	super.clear();

	this.ni = null;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "NetworkService["
	    + super.toString()
	    + "; ni="
	    + this.ni
	    + "]";
    }
}
