/*
 * RevokableInputStream.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.resource;

import java.io.IOException;
import java.io.InputStream;
import java.io.EOFException;

public final class RevokableInputStream
    extends InputStream
{
    private final InputStream real;
    private InputStream in;

    protected RevokableInputStream(InputStream in)
    {
	this.real = in;
	this.in = in;
    }

    void grant()
    {
	this.in = this.real;
    }
    
    void revoke()
    {
	this.in = null;
    }
    
    public int available()
	throws IOException
    {
	try
	{
	    return (in.available());
	}
	catch (NullPointerException _)
	{
	    return (0);
	}
    }

    public void close()
	throws IOException
    {
	try
	{
	}
	catch (NullPointerException _)
	{
	}
    }

    public synchronized void mark(int readlimit)
    {
	try
	{
	    in.mark(readlimit);
	}
	catch (NullPointerException _)
	{
	}
    }

    public boolean markSupported()
    {
	try
	{
	    return (in.markSupported());
	}
	catch (NullPointerException _)
	{
	    return (false);
	}
    }

    public int read()
	throws IOException
    {
	try
	{
	    return (in.read());
	}
	catch (NullPointerException _)
	{
	    throw new EOFException("null stream");
	}
    }

    public int read(byte b[])
	throws IOException
    {
	return (read(b, 0, b.length));
    }

    public int read(byte b[], int off, int len)
	throws IOException
    {
	try
	{
	    return (in.read(b, off, len));
	}
	catch (NullPointerException _)
	{
	    throw new EOFException("null stream");
	}
    }

    public synchronized void reset()
	throws IOException
    {
	try
	{
	    in.reset();
	}
	catch (NullPointerException _)
	{
	    throw new IOException("null stream");
	}
    }

    public long skip(long n)
	throws IOException
    {
	try
	{
	    return (in.skip(n));
	}
	catch (NullPointerException _)
	{
	    throw new EOFException("null stream");
	}
    }
    public String toString()
    {
	return "RevokableInputStream["
	    + super.toString()
	    + "; in="
	    + this.in
	    + "]";
    }
}
