/*
 * RevokableOutputStream.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.resource;

import java.io.IOException;
import java.io.OutputStream;

public final class RevokableOutputStream
    extends OutputStream
{
    private final OutputStream real;
    private OutputStream out;
    
    RevokableOutputStream(OutputStream os)
    {
	this.real = os;
	this.out = os;
    }

    void grant()
    {
	this.out = this.real;
    }
    
    void revoke()
    {
	this.out = null;
    }
    
    public void close()
	throws IOException
    {
	try
	{
	    flush();
	}
	catch(NullPointerException e)
	{
	}
    }

    public void flush()
	throws IOException
    {
	try
	{
	    out.flush();
	}
	catch(NullPointerException e)
	{
	}
    }
    
    public void write(byte b[])
	throws IOException
    {
	try
	{
	    write(b, 0, b.length);
	}
	catch(NullPointerException e)
	{
	}
    }
    
    public void write(byte b[], int off, int len)
	throws IOException
    {
	try
	{
	    out.write(b, off, len);
	}
	catch(NullPointerException e)
	{
	}
    }
    
    public void write(int b)
	throws IOException
    {
	try
	{
	    out.write(b);
	}
	catch(NullPointerException e)
	{
	}
    }
    
    public String toString()
    {
	return "RevokableOutputStream["
	    + super.toString()
	    + "; out="
	    + this.out
	    + "]";
    }
}
