/*
 * Alias.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.security;

import java.util.Hashtable;
import java.util.Enumeration;

import bees.core.Assert;
import bees.core.ObjectMap;
import bees.core.Capability;

public final class Alias
    extends GuardedStringCapability
    implements ObjectMap
{
    private Hashtable map = new Hashtable();

    public void revoke()
    {
	Enumeration enum;
	Hashtable ht;
	
	synchronized( this )
	{
	    super.revoke();
	    ht = this.map;
	    this.map = null;
	}
	enum = ht.elements();
	while( enum.hasMoreElements() )
	{
	    Capability cap = (Capability)enum.nextElement();

	    cap.revoke();
	}
    }

    public Object get(Object key)
    {
	return this.map.get(key);
    }
    
    public Object remove(Object key)
    {
	return this.map.remove(key);
    }
    
    public Object put(Object key, Object value)
    {
	return this.map.put(key, value);
    }

    public Enumeration keys()
    {
	return this.map.keys();
    }
    
    public Enumeration elements()
    {
	return this.map.elements();
    }

    public int size()
    {
	return this.map.size();
    }
    
    public String toString()
    {
	return "Alias["
	    + super.toString()
	    + "; map="
	    + this.map
	    + "]";
    }
}
