/*
 * AliasFactory.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.security;

import bees.core.Xdr;
import bees.core.XdrByteArray;

import bees.core.kernel.KernelObjectCoroutine;

import bees.core.bdomain.BDomain;

public final class AliasFactory
{
    static byte[] marshal(String alias)
    {
	XdrByteArray xba;

	xba = new XdrByteArray(Xdr.STRING(alias));
	xba.PUT(alias);
	return xba.toBytes();
    }

    private final BDomain bdomain;
    
    public AliasFactory()
    {
	this.bdomain = BDomain.currentBDomain();
    }

    public synchronized Alias create(Alias parent,
				     String alias,
				     String comment)
    {
	String pAlias;

	pAlias = parent.getValue();
	if( pAlias == null )
	    throw new SecurityException("Revoked parent");
	alias = pAlias + alias;
	return (Alias)KernelObjectCoroutine.
	    create(new Alias(),
		   this.bdomain.getBDomainCoroutine(),
		   marshal(alias),
		   comment);
    }

    public synchronized Alias create(Alias parent, String alias)
    {
	return this.create(parent, alias, "Alias");
    }

    public String toString()
    {
	return "AliasFactory["
	    + "]";
    }
}
