/*
 * EnumerationPair.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.security;

/**
 * An EnumerationPair maps a string to an integer value.
 */
public final class EnumerationPair
{
    /**
     * The symbol name.
     */
    private final String string;

    /**
     * The symbol's integer value.
     */
    private final int id;

    /**
     * Construct an EnumerationPair with the given values.
     *
     * @param string The symbol name.
     * @param id The symbol's integer value.
     */
    public EnumerationPair(String string, int id)
    {
	this.string = string;
	this.id = id;
    }

    /**
     * @return The symbol name.
     */
    public String getString()
    {
	return this.string;
    }

    /**
     * @return The symbol's integer value.
     */
    public int getID()
    {
	return this.id;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "EnumerationPair[string="
	    + this.string
	    + "; id="
	    + this.id
	    + "]";
    }
}
