/*
 * KeyPair.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.security;

/**
 * This class is a simple holder for a key pair (a public key and a private
 * key). It does not enforce any security, and, when initialized, should be
 * treated like a PrivateKey.
 */
public final class KeyPair
{
    /**
     * The private key.
     */
    private final PrivateKey prvKey;

    /**
     * The public key.
     */
    private final PublicKey pubKey;

    /**
     * Construct a KeyPair with the given values.
     *
     * @param prvKey The private key.
     * @param pubKey The public key.
     */
    public KeyPair(PrivateKey prvKey, PublicKey pubKey)
    {
	this.prvKey = prvKey;
	this.pubKey = pubKey;
    }

    /**
     * @return The private key.
     */
    public PrivateKey getPrivate()
    {
	return this.prvKey;
    }

    /**
     * @return The public key.
     */
    public PublicKey getPublic()
    {
	return this.pubKey;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "KeyPair[prvKey="
	    + this.prvKey
	    + "; pubKey="
	    + this.pubKey
	    + "]";
    }
}
