/*
 * PrivateKey.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.security;

import java.security.NoSuchAlgorithmException;

import java.security.spec.InvalidKeySpecException;

/**
 * A PrivateKey capability wraps a java.security.PrivateKey object.  This makes
 * it possible to pass the object to untrusted code without leaking the key
 * material.
 */
public final class PrivateKey
    extends PrivateKeySpec
{
    /**
     * The default permissions for a PrivateKey capability.
     */
    public static final PermissionSet DEFAULT_PERMISSIONS =
	new PermissionSet();
    
    /**
     * Construct an empty PrivateKey.
     */
    public PrivateKey()
    {
    }

    /**
     * @see bees.core.Capability#fromBytes(byte[])
     */
    protected final void fromBytes(byte flattened[])
	throws NoSuchAlgorithmException,
	       InvalidKeySpecException,
	       Exception
    {
	super.fromBytes(flattened);

	super.specFromBytes(flattened);
    }

    /**
     * @see bees.core.Capability#revoke()
     */
    public synchronized void revoke()
    {
	super.clear();
	
	this.pk = null;
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "PrivateKey["
	    + super.toString()
	    + "]";
    }
}
