/*
 * SecretKey.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.core.security;

/**
 * A SecretKey capability wraps a javax.crypto.SecretKey object.  This makes
 * it possible to pass the object to untrusted code without leaking the key
 * material.
 */
public final class SecretKey
    extends SecretKeySpec
{
    /**
     * Permission to read the encoded version of this key.
     */
    private static final Permission ENCODED_PERMISSION =
	new Permission("encoded", "read");

    /**
     * The default permissions for a new SecretKey capability.
     */
    public static final PermissionSet DEFAULT_PERMISSIONS =
	new PermissionSet(new Permission[] {
	    new Permission("encoded", ""),
	    new Permission("delete", "execute"),
	});

    /**
     * The wrapped key.
     */
    javax.crypto.SecretKey sk;
    
    /**
     * Construct an empty SecretKey.
     */
    public SecretKey()
    {
    }
    
    /**
     * @see bees.core.Capability#fromBytes(byte[])
     */
    protected void fromBytes(byte flattened[])
	throws Exception
    {
	super.fromBytes(flattened);

	super.specFromBytes(flattened);
    }

    /**
     * @see bees.core.security.KeySpec#toBytes()
     */
    public synchronized byte[] toBytes()
    {
	super.checkPermission(ENCODED_PERMISSION);

	return super.toBytes();
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString()
    {
	return "SecretKey["
	    + super.toString()
	    + "]";
    }
}
