/*
 * ClockTest.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.tests;

import bees.core.Node;
import bees.core.ObjectMap;
import bees.core.ObjectTree;
import bees.core.SignedXdrByteArray;

import bees.core.resource.Clock;
import bees.core.resource.Logger;
import bees.core.resource.Console;
import bees.core.resource.Directory;
import bees.core.resource.LoggerSpec;
import bees.core.resource.LoggerFactory;

import bees.core.security.PublicKey;
import bees.core.security.Signature;
import bees.core.security.PrivateKey;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.PermissionException;

public final class ClockTest
    implements Test
{
    private static final String SIG_ALGORITHM = "DSA";
    
    public void test(Node node)
	throws Throwable
    {
	Clock clock;

	clock = (Clock)node.getCapability("clock");
	{
	    final long TOLERANCE = 1000;

	    SignedXdrByteArray sally, victor;
	    PrivateKey prvKey;
	    PublicKey pubKey;
	    ObjectMap om;
	    byte sig[];
	    short lob;

	    om = node.getCapabilityMap("keys");
	    prvKey = (PrivateKey)om.get("private");
	    pubKey = (PublicKey)om.get("public");
	    
	    sally = new SignedXdrByteArray(SignedXdrByteArray.TIMESTAMP,
					   SIG_ALGORITHM);
	    sally.PUT(clock);
	    sally.sign(prvKey);

	    node.sleep(250);
	    
	    victor = new SignedXdrByteArray(sally.buf,
					    sally.getSignature(),
					    SIG_ALGORITHM);
	    if( victor.verify(pubKey) )
	    {
		Logger.log("Verified!");
	    }
	    
	    if( victor.TIMESTAMP(clock, TOLERANCE) )
	    {
		Logger.log("Valid time");
	    }
	    
	    node.sleep(2 * TOLERANCE);

	    victor.index = 0;
	    if( !victor.TIMESTAMP(clock, TOLERANCE) )
	    {
		Logger.log("Invalid time");
	    }
	}
    }
}
