/*
 * KeyTest.java
 *
 * Copyright (c) 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the Janos Bees Software.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation is hereby granted without fee, provided that the above
 * copyright notice and this permission/disclaimer notice is retained in all
 * copies or modified versions, and that both notices appear in supporting
 * documentation.  THE COPYRIGHT HOLDERS PROVIDE THIS SOFTWARE "AS IS" AND
 * WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE.  THE COPYRIGHT HOLDERS DISCLAIM ANY LIABILITY OF ANY KIND FOR
 * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
 * 
 * Users are requested, but not required, to send to csl-dist@cs.utah.edu any
 * improvements that they make and grant Univ. of Utah redistribution rights.
 */

package bees.tests;

import bees.core.Xdr;
import bees.core.Node;
import bees.core.ByteArray;
import bees.core.ObjectMap;
import bees.core.Capability;
import bees.core.ObjectTree;
import bees.core.CipheredXdrByteArray;

import bees.core.resource.File;
import bees.core.resource.Logger;
import bees.core.resource.Console;
import bees.core.resource.Directory;
import bees.core.resource.LoggerSpec;
import bees.core.resource.LoggerFactory;
import bees.core.resource.FileSystemRoot;

import bees.core.security.Mac;
import bees.core.security.Cipher;
import bees.core.security.KeySpec;
import bees.core.security.PublicKey;
import bees.core.security.SecretKey;
import bees.core.security.PrivateKey;
import bees.core.security.KeyGenerator;
import bees.core.security.PublicKeySpec;
import bees.core.security.PrivateKeySpec;

import bees.core.security.Permission;
import bees.core.security.PermissionSet;
import bees.core.security.FilePermission;
import bees.core.security.PermissionException;

public final class KeyTest
    implements Test
{
    private static final String DATA = "Hello, World!";
    
    public void test(Node node)
	throws Throwable
    {
	PrivateKey prvKey;
	PublicKey pubKey;
	SecretKey sk;
	ObjectMap om;

	om = node.getCapabilityMap("keys");
	
	prvKey = (PrivateKey)om.get("private");
	pubKey = (PublicKey)om.get("public");

	sk = new KeyGenerator().
	    generateKey("DES", 0, new PermissionSet(new Permission[] {
		Cipher.ENCRYPT_PERMISSION,
		Cipher.DECRYPT_PERMISSION,
		Capability.DELETE_PERMISSION,
		}));

	{
	    CipheredXdrByteArray xba;
	    byte old[];

	    xba = new CipheredXdrByteArray(Xdr.STRING(DATA),
					   "DES/CBC/PKCS5Padding");
	    xba.PUT("Hello, World!");
	    old = xba.buf;
	    xba.encrypt(sk);

	    if( old == xba.buf )
		Logger.log("Buffers are the same after encryption?");
	    xba.index = 0;

	    xba.decrypt(sk);
	    Logger.log(xba.STRING());
	}

	sk.deleteCapability();
	
	sk = new KeyGenerator().
	    generateKey("DES", 0, new PermissionSet(new Permission[] {
		Mac.MAC_PERMISSION,
		Capability.DELETE_PERMISSION,
		}));

	{
	    byte bits[];
	    Mac mac;

	    mac = new Mac("DESMac");
	    mac.init(sk);
	    mac.update(DATA.getBytes());
	    bits = mac.doFinal();
	    
	    mac.update(DATA.getBytes());
	    if( new String(bits).equals(new String(mac.doFinal())) )
	    {
		Logger.log("MAC worked");
	    }
	}

	sk.deleteCapability();
    }
}
